# Dreamcoat

![Tests](https://github.com/mvdh7/dreamcoat/workflows/tests/badge.svg)
[![PyPI version](https://img.shields.io/pypi/v/dreamcoat.svg?style=popout)](https://pypi.org/project/dreamcoat/)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/dreamcoat.svg?style=popout)](https://anaconda.org/conda-forge/dreamcoat)
[![DOI](https://img.shields.io/badge/DOI-10.5281%2Fzenodo.8063224-informational)](https://doi.org/10.5281/zenodo.8063224)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

The joyful oceanographic seagoing expedition planning helper

## Version list

![versions](https://raw.githubusercontent.com/mvdh7/dreamcoat/038cba417db0ed9cd51358b123268fb9ace88aa0/docs/versions.svg)
